@@ -20,6 +20,7 @@ import Control.Monad
 import Data.Semigroup
 #ifdef MIN_VERSION_hashable
 import Data.Hashable (Hashable(..))
+import Data.Hashable.Lifted (Hashable1(..))
 #endif
 import Data.Key
 import Data.Functor.Bind
@@ -149,4 +150,8 @@ instance (Storable.Storable a, Hashable a) => Hashable (Storable.Vector a) where
 instance (Primitive.Prim a, Hashable a) => Hashable (Primitive.Vector a) where
   hashWithSalt salt = hashWithSalt salt . Primitive.toList
   {-# INLINE hashWithSalt #-}
+
+instance Hashable1 Vector where
+  liftHashWithSalt itemHashWithSalt salt = liftHashWithSalt itemHashWithSalt salt . Vector.toList
+  {-# INLINE liftHashWithSalt #-}
 #endif
